@@ -1,9 +1,9 @@
-#' \code{photosynthesis} package
+#' `photosynthesis` package
 #'
 #' Tools for Plant Ecophysiology & Modeling
 #'
 #' See the README on
-#' \href{https://github.com/cdmuir/photosynthesis}{GitHub}
+#' [GitHub](https://github.com/cdmuir/photosynthesis)
 #'
 #' @docType package
 #' @name photosynthesis-package
@@ -13,7 +13,7 @@
 #' @importFrom methods is
 #' @importFrom nlme lmList
 #' @importFrom rlang .data
-#' @importFrom stats coef lm optim plogis resid
+#' @importFrom stats coef lm optim plogis resid rnorm
 #' @importFrom units as_units drop_units set_units
 NULL
 
@@ -23,5 +23,5 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("."))
 ## quiets concerns of R CMD check re: units
 utils::globalVariables(c(
   ".A", ".C", ".phiPSII", ".Q", ".Qabs", "degreeC", "g", "hPa", "J", "K", "kg", 
-  "kJ", "kPa", "m", "mol", "normal", "Pa", "PPFD", "s", "umol", "W"
+  "kJ", "kPa", "m", "mol", "mmol", "normal", "Pa", "PPFD", "s", "umol", "W"
 ))
